@@ -22,7 +22,7 @@ import shutil
 from .exceptions import DSLibraryDataFormatException, DSLibraryException
 from .engine_intf import GenericStreamWrapper, BytesIOWrapper
 from .proto_handlers import load_protocol_handler
-from .utils.connect import connect_to_database, dataframe_to_sql
+from .utils.connect import connect_to_database, dataframe_to_sql, db_conn_flavor
 from .utils.dbconn import sql_enquote_id
 from .utils.file_utils import write_stream_with_read_on_close, connect_to_filesystem, adapt_fsspec_storage_options
 from .utils.format_sniffer import find_url_extension, detect_format
@@ -861,7 +861,7 @@ class DSLibrary(object):
                 table = open_args.pop("sql_table", None)
                 db_conn = self.get_sql_connection(resource_name, **open_args)
                 if table:
-                    flavor = getattr(db_conn, "_flavor") if hasattr(db_conn, "_flavor") else None
+                    flavor = db_conn_flavor(db_conn)
                     sql = f"SELECT * from {sql_enquote_id(table, dotted=True, mode=flavor)}"
                 try:
                     c = db_conn.cursor()
