@@ -127,6 +127,15 @@ class DSLibraryViaMMLibrary(DSLibrary):
             return super(DSLibraryViaMMLibrary, self).log_metric(metric_name, metric_value, step)
         self._mm.save_kpi(metric_name, metric_value)
 
+    def get_metrics(self, metric_name: str = None, uri: str = None, time_range: (list, tuple) = None, limit: int = None):
+        if self._mlflow_metrics:
+            return super(DSLibraryViaMMLibrary, self).get_metrics(metric_name, uri, time_range, limit)
+        # NOTE: mmlibrary doesn't support retrieval by time - we are ignoring time_range
+        metric = self._mm.get_last_kpi(metric_name)
+        if not metric:
+            return []
+        return [DSLibrary.Metric(run_id=None, uri=None, user=None, time=metric.get("timestamp"), name=metric_name, value=metric.get("value"), step=None)]
+
     def open_run_data(self, filename: str, mode: str='rb', **kwargs) -> io.IOBase:
         """
         The method provided by mmlibrary to save 'run data' only stores a single chunk of binary data.  We
