@@ -128,8 +128,10 @@ def connect_psycopg2(host, port=None, username=None, password=None, database=Non
         conn.set_isolation_level(psycopg2.extensions.ISOLATION_LEVEL_AUTOCOMMIT)
     if not for_write:
         _set_conn_read_only(conn)
-    setattr(conn, "_flavor", "postgres")
-    #conn._flavor = "postgres"
+    try:
+        conn._flavor = "postgres"
+    except:
+        pass
     return conn
 
 
@@ -193,6 +195,17 @@ def dataframe_to_sql(dataframe, table_name: str, append: bool=False):
         yield "%s%s" % (ins0, ", ".join(sqls)), params
 
 
+def db_conn_flavor(connector) -> str:
+    """
+    Determine connector flavor.
+    """
+    if hasattr(connector, "_flavor"):
+        return connector._flavor
+    name = connector.__class__.__name__.lower()
+    if "postg" in name:
+        return "postgres"
+
+
 METHODS = {
     "pymysql": connect_pymysql,
     "psycopg2": connect_psycopg2,
