@@ -80,7 +80,7 @@ def detect_format(
         "yml": ("yaml", {}),
         "tab": ("csv", {"delimiter": "\t"}),
         "tsv": ("csv", {"delimiter": "\t"}),
-        "txt": ("csv", {"delimiter": '\n', "names": ["line"]})
+        "txt": ("csv", {"names": ["line"]})
     }
     orig_format = (format or "").lower()
     if format:
@@ -108,7 +108,7 @@ def detect_format(
         elif fallback_to_text and looks_like_text_file(sample):
             # a single column called 'line'
             format = "csv"
-            read_args.update({"delimiter": '\n', "names": ["line"]})
+            read_args.update({"names": ["line"]})
         # calculate average line size
         avg_line_size = average_line_size(sample)
     # override determined options with supplied values
