@@ -1,7 +1,7 @@
 import unittest
 import pandas
 
-from dslibrary.utils.connect import _process_params, dataframe_to_sql
+from dslibrary.utils.connect import _process_params, dataframe_to_sql, db_conn_flavor, connect_psycopg2
 
 
 class TestConnect(unittest.TestCase):
@@ -48,3 +48,13 @@ class TestConnect(unittest.TestCase):
             ('CREATE TABLE IF NOT EXISTS t1 (x INTEGER, y DOUBLE PRECISION, z VARCHAR(8))', []),
             ('INSERT INTO t1 (x, y, z) VALUES (%s, %s, %s), (%s, %s, %s), (%s, %s, %s)', [1, 1.0, 'one', 2, 2.0, 'two', 3, 4.0, 'three'])
         ])
+
+    def test_db_conn_flavor(self):
+        # artificially set property
+        class A(object):
+            _flavor = "xyz"
+        self.assertEqual(db_conn_flavor(A()), "xyz")
+        # name of class
+        class MyPostGresDriver(object):
+            pass
+        self.assertEqual(db_conn_flavor(MyPostGresDriver()), "postgres")
